[![Documentation Status](https://readthedocs.org/projects/tof/badge/?version=latest)](https://tof.readthedocs.io/en/latest/?badge=latest)

# tof

A simple tool to create time-of-flight chopper cascade diagrams

**Scope:**

- ``tof`` is designed to be simple and lightweight, it will never replace [McStas](https://www.mcstas.org/)
- it assumes all neutrons travel in a straight line
- it does not simulate absorption or scattering effects

## Installation

```sh
pip install tof
```

## Documentation

[https://tof.readthedocs.io/](https://tof.readthedocs.io/)

![example](https://tof.readthedocs.io/en/latest/_images/short-example_13_1.png)
